@@ -1,10 +1,10 @@
 package Bundle::W3C::Validator;
 
-use 5.6.0;
+use 5.8.0;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.7.0';
+$VERSION = '0.8.0';
 
 1;
 
@@ -22,13 +22,18 @@ C<perl -MCPAN -e "install Bundle::W3C::Validator">
 
  CGI 2.81
  Config::General 2.19
+ Encode
+ Encode::HanExtra
+ Encode::JIS2K
+ File::Spec
+ HTML::Encoding 0.52
  HTML::Parser 3.25
  HTML::Template 2.6
  LWP::UserAgent 1.90
  Net::IP
- Set::IntSpan
- Text::Iconv
+ SGML::Parser::OpenSP
  URI
+ XML::LibXML
 
 =head1 DESCRIPTION
 
@@ -46,7 +51,7 @@ The W3C Markup Validator Team, E<lt>www-validator@w3.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 1994-2005 World Wide Web Consortium, (Massachusetts
+Copyright (C) 1994-2007 World Wide Web Consortium, (Massachusetts
 Institute of Technology, European Research Consortium for Informatics
 and Mathematics, Keio University). All Rights Reserved. This work is
 distributed under the W3C(R) Software License [1] in the hope that it
